==> haskell-mountpoints-1.0.2-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mountpoints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mountpoints
version:              1.0.2
visibility:           public
id:                   mountpoints-1.0.2-1Te2HjQFc4LCW1HkVDH9ky
key:                  mountpoints-1.0.2-1Te2HjQFc4LCW1HkVDH9ky
license:              LicenseRef-LGPL
copyright:            2012 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             list mount points
description:
    Lists currently mounted filesystems.

    Works on: Linux, BSD, Mac OS X, Android

category:             System
abi:                  e800561bb8551feecbb84f5e37e23c4f
exposed:              True
exposed-modules:      System.MountPoints
import-dirs:          /usr/lib/ghc-8.8.3/site-local/mountpoints-1.0.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/mountpoints-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/mountpoints-1.0.2
hs-libraries:         HSmountpoints-1.0.2-1Te2HjQFc4LCW1HkVDH9ky
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-mountpoints/html/mountpoints.haddock
haddock-html:         /usr/share/doc/haskell-mountpoints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mountpoints-1.0.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mountpoints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mountpoints
version:              1.0.2
visibility:           public
id:                   mountpoints-1.0.2-8H4a2zuSeie7Yh1BTT9kAO
key:                  mountpoints-1.0.2-8H4a2zuSeie7Yh1BTT9kAO
license:              LicenseRef-LGPL
copyright:            2012 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             list mount points
description:
    Lists currently mounted filesystems.

    Works on: Linux, BSD, Mac OS X, Android

category:             System
abi:                  bb9d6b370bb0155bf24fb358a7899d92
exposed:              True
exposed-modules:      System.MountPoints
import-dirs:          /usr/lib/ghc-8.10.1/site-local/mountpoints-1.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/mountpoints-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/mountpoints-1.0.2
hs-libraries:         HSmountpoints-1.0.2-8H4a2zuSeie7Yh1BTT9kAO
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-mountpoints/html/mountpoints.haddock
haddock-html:         /usr/share/doc/haskell-mountpoints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
